import unittest

from coinwise import CoinWise
from . import staging_test_confs


class CoinWiseIntegrationTest(unittest.TestCase):

    def setUp(self):
        self.confs = staging_test_confs
        username = self.confs.USERNAME
        password = self.confs.PASSWORD
        client_id = self.confs.CLIENT_ID
        instance_id = self.confs.INSTANCE_ID
        self.coinwise = CoinWise(
            username=username, password=password, client_id=client_id, instance_id=instance_id
        )

    def test_login(self):
        response = self.coinwise.login()
        expected_response = {'name': 'Inflr', 'coin': 'BTC'}
        self.assertEqual(200, response.status_code)
        self.assertEqual(expected_response, response.json())


if __name__ == '__main__':
    unittest.main()



class CoinWiseInvalidUserException(Exception):
    def __init__(self):
        self.message = 'Invalid username or password'


class CoinWiseException(Exception):
    def __init__(self, message):
        self.message = message



import requests
import urllib.parse
import status

from coinwise import coinwise_confs
from coinwise.exceptions import CoinWiseInvalidUserException, CoinWiseException


class CoinWise(object):
    def __init__(self, username, password, client_id, instance_id, http_client=requests, staging_mode=True):
        self.instance_id = instance_id
        self.client_id = client_id
        self.conf = coinwise_confs
        self.password = password
        self.username = username
        self.http_client = http_client
        self.base_url = self.conf.STAGING_URL if staging_mode else self.conf.PRODUCTION_URL

    def login(self):
        path = 'login'
        return self.__get(path=path)

    def create_invoice(self, value, extra_msg, label, hex_dark, hex_light):
        params = {
            'value': value, 'extra': extra_msg, 'label': label, 'dark': hex_dark, 'light': hex_light
        }
        return self.__get(params=params)

    def check_invoice(self, invoice_id, waitting_method=False):
        path = '{invoice_id}'.format(invoice_id=invoice_id)
        params = {}
        if waitting_method:
            params = {'transition': 'new­incoming'}
        return self.__get(path=path, params=params)

    def invoce_history(self, number_invoices=100):
        path = 'history'
        params = {"last": number_invoices}
        return self.__get(path=path, params=params)


    def __get(self, path=None, params={}):
        url = self.__url_join(path)
        print(url)
        print(params)
        response = requests.get(url, params=params, headers=self.__headers(), auth=(self.username, self.password))
        return response

    def __url_join(self, path):
        if path:
            url = urllib.parse.urljoin(self.base_url, path)
        else:
            url = self.base_url[:-1]
        return url.format(client_id=self.client_id, instance_id=self.instance_id)

    def __headers(self):
        return {
            'Content-Type': 'application/json'
        }





from setuptools import setup, find_packages

from os import path

here = path.abspath((path.dirname(__file__)))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()



setup(
    name='coinwise-sdk',
    version=0.1,
    description='CoinWise integration',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/GuilhermeGPG/coinwise-sdk',
    author='Guilherme Gomides',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6'
    ],
    keywords='Coinwise integration',
    author_email='guilhermepgomides@gmail.com',
    license='MIT',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    install_requires=['requests', 'python-status'],
    zip_safe=False
)